@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 import doctest
 import logging
 import os
@@ -65,7 +66,7 @@ class IntegrationTest(unittest.TestCase):
         GitHub issue #41.
         """
         extractor = tldextract.TLDExtract(suffix_list_url='foo', fetch=False)
-        assert not extractor.suffix_list_url
+        assert not extractor.suffix_list_urls
 
 class ExtractTest(unittest.TestCase):
     def assertExtract(self, expected_subdomain, expected_domain, expected_tld, url,
@@ -111,6 +112,9 @@ class ExtractTest(unittest.TestCase):
         self.assertExtract('', '216.22.0.192', '', 'http://216.22.0.192/')
         self.assertExtract('216.22', 'project', 'coop', 'http://216.22.project.coop/')
 
+    def test_punycode(self):
+        self.assertExtract('', u'россия', u'рф', 'http://xn--h1alffa9f.xn--p1ai')
+
     def test_empty(self):
         self.assertExtract('', '', '', 'http://')
 
