@@ -25,6 +25,7 @@ try:
     import cPickle as pickle
 except ImportError:
     import pickle
+import codecs
 from contextlib import closing
 import errno
 from functools import wraps
@@ -207,6 +208,10 @@ class TLDExtract(object):
           .partition(":")[0] \
           .rstrip(".")
 
+        is_punycode = netloc.startswith('xn--') or '.xn--' in netloc
+        if is_punycode:
+            netloc = codecs.decode(netloc.encode('ascii'), 'idna')
+
         registered_domain, tld = self._get_tld_extractor().extract(netloc)
         if not tld and netloc and netloc[0].isdigit():
             try:
@@ -235,7 +240,7 @@ class TLDExtract(object):
 
         if self.cache_file:
             try:
-                with open(self.cache_file) as f:
+                with open(self.cache_file, 'rb') as f:
                     self._extractor = _PublicSuffixListTLDExtractor(pickle.load(f))
                     return self._extractor
             except IOError as ioe:
@@ -352,9 +357,9 @@ def main():
     distribution = pkg_resources.get_distribution('tldextract')
 
     parser = argparse.ArgumentParser(
-        version='%(prog)s ' + distribution.version,
         description='Parse hostname from a url or fqdn')
 
+    parser.add_argument('--version', action='version', version='%(prog)s ' + distribution.version)
     parser.add_argument('input', metavar='fqdn|url',
                         type=unicode, nargs='*', help='fqdn or url')
 
